# Access Token Auth
The Access Token Auth module enables the generation of access tokens for authenticating requests within Drupal.

Other modules that this was based on:
- [REST API Access Token](https://www.drupal.org/project/rest_api_access_token)
- [Simple OAuth (OAuth2) & OpenID Connect](https://www.drupal.org/project/simple_oauth)

## Features
The Access Token Auth module focuses solely on the creation of access tokens, making it a straightforward solution. However, it's important to consider permissions because the generated token will authenticate requests as the user who generated the token, which is the currently logged-in user.

### Configuration
The module offers two types of settings for the generated access tokens: `Time-based` and `One-time use`.

If the user modifies the settings while tokens have already been generated, the existing tokens will adapt to the current settings. This means that regardless of the original configuration, the module automatically adjusts the tokens. For example, if a token was generated with the `Time-based` option and has already been used but remains valid within the time window, changing the settings to `One-time` will mark the token as used, as it was already used. The same behavior applies in the opposite scenario.

#### Time-based
This is the default option, which sets a Time To Live (TTL) in seconds for the generated access tokens. The tokens remain valid for a specified period of time. By default, the TTL value is set to `180` seconds.

#### One-time use
This option allows tokens to be used only once.

### Authentication
To authenticate using the generated token, you have two options: `headers` or `parameters`.

Regardless of your choice, you only need to include the `X-ACCESS-AUTH-TOKEN` variable with the token value.

## Usage
Using the Access Token Auth module is straightforward. Follow these steps:

### Generate token
1. Enable the module.
2. Go to `/admin/config/services/access-token-auth-settings`.
3. Configure the settings according to your preferences and save the changes.
4. Press the `Generate Token` button.

### Authenticate with access token
1. In your preferred client, pass the token value using the `X-ACCESS-AUTH-TOKEN` variable name.
   - You can pass in via headers or query paramaters.
2. That's it!

## How to use in code
The module exposes two services: the `Token Generator` and the `Token Manager`.

### Access Token Generator
The `access_token_auth.token_generator` service allows you to generate tokens programmatically.

### Token Manager
The `access_token_auth.token_manager` service manages the stored tokens and provides methods for interacting with them.
