<?php

namespace Drupal\access_token_auth;

use Drupal\access_token_auth\Model\Token;

/**
 * Interface for token generator services.
 */
interface TokenGeneratorInterface {

  /**
   * Generates a unique access token.
   *
   * This method generates a unique access token and persists it in the database
   * for verification purposes.
   *
   * @param int $user_id
   *   The user id of the user generating the token.
   *
   * @return \Drupal\access_token_auth\Model\Token|null
   *   The token object or NULL if there was an error while generating it.
   */
  public function generateToken(int $user_id): ?Token;

  /**
   * Generates a unique transient token.
   *
   * This function generates a unique token that is intended for temporary use
   * and is not persisted in the database.
   *
   * @param int $user_id
   *   The user id.
   *
   * @return \Drupal\access_token_auth\Model\Token
   *   The token object.
   *
   * @throws \Drupal\access_token_auth\Exception\TokenGeneratorException
   *   When hash algorithm generate empty string.
   */
  public function generateTransientToken(int $user_id): Token;

}
